﻿using System.Collections.Generic;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace AutoSelectAllUltraRows
{
  public partial class Form1 : Form
  {
    public Form1()
    {
      InitializeComponent();
      SetUpDisplayLayout();
      SetDataSource();
    }

    private void SetUpDisplayLayout()
    {
      _grid.DisplayLayout.Override.RowSelectors = DefaultableBoolean.True;
      _grid.DisplayLayout.Override.RowSelectorWidth = 20;
      _grid.DisplayLayout.Override.CellClickAction = CellClickAction.CellSelect;
      _grid.DisplayLayout.Override.RowSelectorHeaderStyle = RowSelectorHeaderStyle.SeparateElement;
      _grid.DisplayLayout.Override.RowSizing = RowSizing.Fixed;
      _grid.DisplayLayout.Override.RowSpacingAfter = 0;
      _grid.DisplayLayout.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;
    }

    public void SetDataSource()
    {
      var personsFactory = new PersonsFactory();
      _grid.DataSource = personsFactory.CreatePersons();
    }

    public class PersonsFactory
    {
      public IList<Person> CreatePersons()
      {
        IList<Person> persons = new List<Person>
                                  {
                                    new Person("Person1", 50, "Address1"),
                                    new Person("Person2", 38, "Address2"),
                                    new Person("Person3", 30, "Address3"),
                                    new Person("Person4", 28, "Address4"),
                                    new Person("Person5", 48, "Address5"),
                                    new Person("Person6", 43, "Address6")
                                  };
        return persons;
      }
    }

    public class Person
    {
      public Person(string name_, int age_, string address_)
      {
        Name = name_;
        Age = age_;
        Address = address_;
        IList<Employee> list = new List<Employee>
                                 {
                                   new Employee("Employee1", 44, "Address2"),
                                   new Employee("Employee2", 20, "Address2"),
                                   new Employee("Employee3", 25, "Address2"),
                                   new Employee("Employee4", 34, "Address2")
                                 };
        EmployeeList = list;
      }

      public string Name { get; private set; }
      public int Age { get; private set; }
      public string Address { get; private set; }
      public IList<Employee> EmployeeList { get; private set; }
    }

    public class Employee
    {
      public Employee(string name_, int age_, string address_)
      {
        Name = name_;
        Age = age_;
        Address = address_;
      }

      public string Name { get; private set; }
      public int Age { get; private set; }
      public string Address { get; private set; }
    }
  }
}